import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="mms-alice-testpackage",
    version="0.0.6",
    author="Josef Goppold",
    author_email="goppold@mediamarktsaturn.com",
    description="This is a test",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/EastOfGondor/mms-alice-python-packages",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: MacOS",   
    ],
)




class MMS_TestClass:
	def __init__(self, a, b):
		self.a = a
		self.b = b

	def add(self):
		return self.a + self.b

	def abs_diff(self, val1, val2):
		return abs(val1-val2)

	def output(self):
		return 'Kack Fabi! Beeil dich! Wir ham Hunger!'
